@@ -92,6 +92,8 @@ typedef enum{
   AGS_WAVE_EDIT_KEY_R_CONTROL       = 1 <<  1,
   AGS_WAVE_EDIT_KEY_L_SHIFT         = 1 <<  2,
   AGS_WAVE_EDIT_KEY_R_SHIFT         = 1 <<  3,
+  AGS_WAVE_EDIT_KEY_L_META          = 1 <<  4,
+  AGS_WAVE_EDIT_KEY_R_META          = 1 <<  5,
 }AgsWaveEditKeyMask;
 
 struct _AgsWaveEdit
